# 💻 Commands

This section includes all common commands used on dev environment. These commands should be runned in `easy-cozy` directory.

```bash
cd easy-cozy
```

## App

### Install a specific version of an app

```bash
docker-compose exec cozy ./cozy apps update home --domain "[name].cozy.self-data.alpha.grandlyon.com" git://github.com/doubleface/cozy-collect.git#build-debug
```

## Konnector

### Install a specific version of a konnector

```bash
# cozy-stack konnectors uninstall ${konn} --domain ${url}
docker-compose exec cozy ./cozy konnectors uninstall grdfgrandlyon --domain "[name].cozy.self-data.alpha.grandlyon.com"
grdfgrandlyon has been uninstalled
# cozy-stack konnectors install ${konn} --domain ${url}
docker-compose exec cozy ./cozy konnectors install grdfgrandlyon --domain "[name].cozy.self-data.alpha.grandlyon.com" git://forge.grandlyon.com/web-et-numerique/factory/llle_project/grdf-adict-konnector.git#build
grdfgrandlyon (0.1.5) has been installed on [name].cozy.self-data.alpha.grandlyon.com
```

### Update the version of a konnector

```bash
$ cd /easy-cozy
# cozy-stack konnectors update ${konn} --domain ${url}
$ docker-compose exec cozy ./cozy konnectors update grdfgrandlyon --domain "[name].cozy.self-data.alpha.grandlyon.com"
grdfgrandlyon has been upgraded to 0.1.5-d4bbe7350ecf13d13734f559c538e3c0ee8dc7ae
```

### Run a konnector from the stack

```bash
# cozy-stack konnectors run ${konn} --domain ${url}
docker-compose exec cozy ./cozy konnectors run grdfgrandlyon --domain "[name].cozy.self-data.alpha.grandlyon.com"
```

## Instance

### Set log level to debug for an instance

```bash
# cozy-stack instances debug ${url} true
docker-compose exec cozy ./cozy instances debug --domain "[name].cozy.self-data.alpha.grandlyon.com" true
```

#### List all instances

```bash
# cozy-stack instances ls
docker-compose exec cozy ./cozy instances ls
```

## Stack

### Check stack version

```bash
docker-compose exec cozy ./cozy version
```

### Update stack version

Update version in the Dockerfile on gitlab.

**On server :**

1. git pull or change locally the version in cozy-stack/Dockerfile
2. create the docker image using:

   ```bash
   cd /easy-cozy/build
   ./build-docker-image.sh
   ```

3. Start the container based on the built image

   ```bash
   cd ..
   docker-compose up -d cozy
   ```

:::info Error encounter

Docker container was not launched, when consulting logs we can see the following error

> ./cozy: /lib/x86_64-linux-gnu/libc.so.6: version `GLIBC_2.32' not found (required by ./cozy)

We have replaced debian:stable-slim with ubuntu:20.10 as installer for our docker build: https://forge.grandlyon.com/pocs/cozy/easy-cozy/-/commit/48a30a03f209169e0f1ebb0d106bb4361e7cd167

:::

### Manipulate data

To read/write data from the stack you can run the following commands

```sh
docker-compose exec db curl -u [USER]:[PASSWORD] -X [METHOD] http://127.0.0.1:5984/[DATABASE]
```

:warning: When updating a document, make sure to remove the `_id` and to add `_rev` fields
