# Getting started

This section will allow you to launch a proper local environment of the Ecolyo application

:::tip Clone the project

First, clone [Ecolyo](https://forge.grandlyon.com/web-et-numerique/factory/llle_project/ecolyo)

:::

## Installation of the project

### Start the app

Install required node modules, open a terminal on the root folder of the project and type the following command:

```sh
yarn install
```

Start ecolyo application just launch the command:

```sh
yarn start
```

If the application starts successfully you should obtain the following message:

> App successfully compiled!  
> Dev assets: 'http://localhost:8888'

Once the application is started, run the easy-cozy stack with docker.

### Start cozy stack

Launch the stack with the following command:

```sh
docker-compose up
```

:::note If you have an access denied issue
`docker login registry.forge.grandlyon.com`
:::

Wait until the success message:

> Everything is setup. Go to http://ecolyo.cozy.tools:8080/
> To exit, press ^C

Once successful you can launch your local cozy with following url: [Cozy local url](http://cozy.tools:8080/). The password of this instance is set to *"cozy"* by default.

Local database can also be consulted at the following url: [Cozy local DB](http://localhost:5984/_utils/)

## Import mock data

:::info Requirement
Your dev stack should be running to import the mock data
:::

First install ACH using yarn :

```sh
yarn global add cozy-ach
```

Next create the "config.js" file based on the "config.template.js"

:::info You can change the period of data generated by changing the following lines:

```js title="config.js"
const startingDate = DateTime.local()
    // highlight-next-line
    .plus({ days: -120 })
    .startOf('day')
const endingDate = DateTime.local()
    .plus({ days: -1 })
    .startOf('day')
```

Just replace -120 by the value needed

:::
Next launch the script `createDayDataFiles.js` available into the `scripts` folder

```sh
cd scripts
node createDayDataFiles.js
```

Json files with data will be created into `scripts/data` folder.
ACH script `importData.bat` will load the content of the file into your CouchDB (database of your dev stack). Launch it using following commands:

On Windows:

```sh
cd scripts
./importData.bat
```

On Linux:

```sh
cd scripts
./importData.sh
```

:::note
If you cannot execute `ACH` after this command, it may be because you do not have the directory where yarn stores its symbolic links in your `PATH`. Edit it to append the result of `yarn global bin` by executing the following command:

```sh
 export PATH="$PATH:`yarn global bin`"
```

:::

You'll be prompted for a **cozysessid**, you can get it in the web console : in the `application` tab, look for the cookies and just copy the cozysessid value.

A new browser windows will open and asking you approval to import data. Just click on **Approve**

Finally your data is loaded in the Ecolyo Application !

## Simulate konnectors connection

:::info Requirement
Your dev stack should be running to import data needed to simulate konnectors connection
:::

When using local environment, konnectors are not able to connect as in production.
To simulate the connection you can use the script **createConnection.js** available in **scripts** folder.

First update the authorization and cookie information from the "config.js" file (if not created just create it from the "config.template.js" file):

```js
const authorization = 'Bearer xxxxxxxxxxx';
const cookie = 'cozysessid=xxxxxxxxxxx';
```

To obtain your own Bearer and cozysessid you need to have the application launched and display the web console (F12) in your navigator and select the **Network tab**. Just select one request and retrieve information for Request Header:

![Bearer&cozysessid](/img/bearer_cozysessid.png)

Next launch the script :

```sh
node scripts/createConnections.js
```

Your data is now loaded and you can refresh the application to see your konnector connected.
