# Use cozy-doctype in local

In order to be able to use our own cozy-doctype, especially remote doctype here, we need to use them in local.

1/ clone [cozy-doctypes](https://github.com/cozy/cozy-doctypes) repository into your system.
Then, push it into your root project.

2/ After that, add your own remote doctype into cozy-doctype folder:

    - create a new folder ex: org.mps.share
    - push into this folder request file: request

You must declare this doctype into your manifest.webapp file like that :

```json
"share": {
  "description": "Required for searching on back-endTS",
  "type": "org.mps.share",
  "verbs": ["GET", "POST"]
},
```

3/ In cozy-app-dev-with-app.sh, you need to add another option when you serve the cozy-stack:

```sh
cozy-stack serve --allow-root (...) --doctypes /path/to/the/doctype
```

=> in this project :

```sh
cozy-stack serve (...) --doctypes /data/cozy-doctypes
```

:::warning
You need to build and push the newest image on the forge registry when the step 3 is done.
You must have all files, into your docker folder, in LF mode of "End of Line Sequence" !
:::

For this project:

```sh
cd docker
docker build .
docker tag <image_ID_created> registry.forge.grandlyon.com/web-et-numerique/factory/monparcourssocial/mps-usager/cozy-env-doctypes
docker push registry.forge.grandlyon.com/web-et-numerique/factory/monparcourssocial/mps-usager/cozy-env-doctypes:latest
```

4/ The path "/data/cozy-doctypes" is linked to the volume of the cozy-app-dev image.

In order to mount this volume, you need to add it when you run the 'docker run' command :

```
  -v $PWD/cozy-doctypes:/data/cozy-doctypes
```

=> for this project :

```sh
docker run --rm -it -p 8080:8080 -p 5984:5984 -p 8025:8025 -v $PWD/build:/data/cozy-app/mps -v $PWD/data:/usr/local/couchdb/data -v $PWD/docker/disableCSP.yaml:/etc/cozy/cozy.yaml -v $PWD/cozy-doctypes:/data/cozy-doctypes registry.forge.grandlyon.com/web-et-numerique/factory/monparcourssocial/mps-usager/cozy-env-doctypes
```

## How to test your remote doctype ?

### GET

1/ In the request file created. Specify the method and the route to your target URL :

    GET https://pilote-agent-dev.grandlyon.com/api/cozy

or with value in query :

    GET https://pilote-agent-dev.grandlyon.com/api/auth/token/check?token={{token}}

2/ Then, you can test it by :

```js
await client.getStackClient().fetchJSON('GET', '/remote/org.mps.share');
```

or with value in query :

```js
await client
  .getStackClient()
  .fetchJSON('GET', '/remote/org.mps.share?token=eyJhb...');
```

### POST

1/ In the request file created. Specify the method and the route to your target URL :

    POST https://pilote-agent-dev.grandlyon.com/api/auth/token/check
    Content-Type: application/json

    "data"

2/ Then, you can test it by :

```js
const parameters = {
  data: JSON.stringify({
    token: 'eyJhb...',
  }),
};

console.log(
  'call remote ==> ',
  await client
    .getStackClient()
    .fetchJSON('POST', '/remote/org.mps.share', parameters)
);
```
